@@ -160,10 +160,20 @@ public:
 
     SetMain(Lum::VPanel::Create(true,true)
             ->Add(tab)
-            ->AddSpace()
-            ->Add(Lum::ButtonRow::Create(true,false)
-                  ->AddOptional(Lum::Button::Create(_ld(dlgButtonAbout),about,true,false))
-                  ->Add(Lum::Button::CreateClose(GetClosedAction(),true,false))));
+            );
+
+    Lum::Def::Menu *menu=Lum::Def::Menu::Create();
+
+    menu
+      ->GroupProject()
+        ->ActionQuit(GetClosedAction())
+      ->End()
+      ->GroupHelp()
+        //->Action(Lum::Def::Action(Lum::Def::Desc(_ld(menuHelpHelp)),NULL))
+        ->ActionAbout(about)
+      ->End();
+
+    SetMenu(menu);
 
     Dialog::PreInit();
   }
